package opcodes

import "github.com/git-town/git-town/v14/src/vm/shared"

// PushTags pushes newly created Git tags to origin.
type PushTags struct {
	undeclaredOpcodeMethods `exhaustruct:"optional"`
}

func (self *PushTags) Run(args shared.RunArgs) error {
	return args.Git.PushTags(args.Frontend)
}
